@@ -1,64 +1,9 @@
 package Egg::Exception;
 #
-# Copyright 2007 Bee Flag, Corp. All Rights Reserved.
 # Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: Exception.pm 48 2007-03-21 02:23:43Z lushe $
+# $Id: Exception.pm 96 2007-05-07 21:31:53Z lushe $
 #
-use strict;
-
-our $VERSION= '0.01';
-
-package Egg::Error;
-use strict;
-use warnings;
-use Devel::StackTrace;
-use overload  '""' => 'stacktrace';
-use base qw/Class::Accessor::Fast/;
-
-our $IGNORE_PACKAGE= [qw/main Class::C3 Carp NEXT/];
-our $IGNORE_CLASS  = [qw/Egg::Error/];
-
-__PACKAGE__->mk_accessors(qw/errstr frames as_string/);
-
-sub throw {
-	my $error= shift->new(@_);
-	die $error;
-}
-sub new {
-	my $class = shift;
-	my $errstr= join '', @_;
-	my $stacktrace;
-	{
-		local $@;
-		eval{
-		  $stacktrace= Devel::StackTrace->new(
-		    ignore_package   => $IGNORE_PACKAGE,
-		    ignore_class     => $IGNORE_CLASS,
-		    no_refs          => 1,
-		    respect_overload => 1,
-		    );
-		  };
-	  };
-	die $errstr unless $stacktrace;
-	bless {
-	  errstr   => $errstr,
-	  as_string=> $stacktrace->as_string,
-	  frames   => [$stacktrace->frames],
-	  }, $class;
-}
-sub stacktrace {
-	my($self)= @_;
-	my @trace;
-	foreach my $f (@{$self->frames}) {
-		push @trace, $f->filename. ': '. $f->line;
-	}
-	"$self->{errstr} \n\n stacktrace: \n [". join("] \n [", @trace). "] \n";
-}
-
-1;
-
-__END__
 
 =head1 NAME
 
@@ -81,23 +26,91 @@ Egg::Exception - Exception module for Egg.
     }
   }
 
+=head1 DESCRIPTION
+
+This is a module to treat the exception handling.
+
+=cut
+use strict;
+
+our $VERSION= '2.00';
+
+package Egg::Error;
+use strict;
+use warnings;
+use Devel::StackTrace;
+use overload  '""' => 'stacktrace';
+use base qw/Class::Accessor::Fast/;
+
+our $IGNORE_PACKAGE= [qw/main Class::C3 Carp NEXT/];
+our $IGNORE_CLASS  = [qw/Egg::Error/];
+
+__PACKAGE__->mk_accessors(qw/ errstr frames as_string /);
+
 =head1 METHODS
 
-=head2 errstr
+Egg::Exception doesn't have the method.
+Please call the method of Egg::Error.
 
-The error message is returned. 
+=head2 new
 
-=head2 frames
+Constructor.
 
-Trace information is returned by the ARRAY reference.
+It processes it by L<Devel::StackTrace>.
 
-=head2 as_string
+=cut
+sub new {
+	my $class = shift;
+	my $errstr= join '', @_;
+	my $stacktrace;
+	{
+		local $@;
+		eval{
+		  $stacktrace= Devel::StackTrace->new(
+		    ignore_package   => $IGNORE_PACKAGE,
+		    ignore_class     => $IGNORE_CLASS,
+		    no_refs          => 1,
+		    respect_overload => 1,
+		    );
+		  };
+	  };
+	die $errstr unless $stacktrace;
+	bless {
+	  errstr   => $errstr,
+	  as_string=> $stacktrace->as_string,
+	  frames   => [$stacktrace->frames],
+	  }, $class;
+}
 
-The error of the Carp style is returned.
+=head2 throw ( [MESSAGE] )
+
+After the exception message is thrown to the constructor, die is done.
+
+  Egg::Error->throw( 'internal error.' );
+
+=cut
+sub throw {
+	my $error= shift->new(@_);
+	die $error;
+}
 
 =head2 stacktrace
 
-The error message and trace information are assembled and it returns it.
+The stack trace that has accumulated is output.
+
+  local $SIG{__DIE__}= sub { Egg::Error->throw(@_) };
+  eval{ ... code. };
+  if ($@) { die $@->stacktrace }
+
+=cut
+sub stacktrace {
+	my($self)= @_;
+	my @trace;
+	foreach my $f (@{$self->frames}) {
+		push @trace, $f->filename. ': '. $f->line;
+	}
+	"$self->{errstr} \n\n stacktrace: \n [". join("] \n [", @trace). "] \n";
+}
 
 =head1 SEE ALSO
 
@@ -118,3 +131,4 @@ at your option, any later version of Perl 5 you may have available.
 
 =cut
 
+1;
